from typing import Any

def hexlify(*args, **kwargs) -> Any: ...

class MQTTClient:
    def ping(self, *args, **kwargs) -> Any: ...
    def publish(self, *args, **kwargs) -> Any: ...
    def wait_msg(self, *args, **kwargs) -> Any: ...
    def subscribe(self, *args, **kwargs) -> Any: ...
    def check_msg(self, *args, **kwargs) -> Any: ...
    def set_last_will(self, *args, **kwargs) -> Any: ...
    def connect(self, *args, **kwargs) -> Any: ...
    def disconnect(self, *args, **kwargs) -> Any: ...
    def set_callback(self, *args, **kwargs) -> Any: ...
    def __init__(self, *argv, **kwargs) -> None: ...

class MQTTException(Exception): ...
